unit sdl_13;

interface
uses Windows;

{$I jedi-sdl.inc}

const
  SDLLibName = 'SDL.dll';

type

  SDL_DisplayMode = record
    format: Uint32;          // pixel format */
    w: integer;              // width */
    h: integer;              // height */
    refresh_rate: integer;   // refresh rate (or zero for unspecified) */
    driverdata: pointer;     // driver-specific data, initialize to 0 */
  end;
  {$EXTERNALSYM SDL_DisplayMode}

  TSdlWindowId = UInt32;
  SDL_WindowID = TSdlWindowId;
  {$EXTERNALSYM SDL_WindowID}

const
  SDL_WINDOWPOS_UNDEFINED = $7FFFFFF;
  SDL_WINDOWPOS_CENTERED = $7FFFFFE;

type

{
 * SDL_WindowEventID
 *
 * Event subtype for window events

    SDL_WINDOWEVENT_NONE,               /**< Never used */
    SDL_WINDOWEVENT_SHOWN,              /**< Window has been shown */
    SDL_WINDOWEVENT_HIDDEN,             /**< Window has been hidden */
    SDL_WINDOWEVENT_EXPOSED,            /**< Window has been exposed and should be redrawn */
    SDL_WINDOWEVENT_MOVED,              /**< Window has been moved to data1,data2 */
    SDL_WINDOWEVENT_RESIZED,            /**< Window size changed to data1xdata2 */
    SDL_WINDOWEVENT_MINIMIZED,          /**< Window has been minimized */
    SDL_WINDOWEVENT_MAXIMIZED,          /**< Window has been maximized */
    SDL_WINDOWEVENT_RESTORED,           /**< Window has been restored to normal size and position */
    SDL_WINDOWEVENT_ENTER,              /**< The window has gained mouse focus */
    SDL_WINDOWEVENT_LEAVE,              /**< The window has lost mouse focus */
    SDL_WINDOWEVENT_FOCUS_GAINED,       /**< The window has gained keyboard focus */
    SDL_WINDOWEVENT_FOCUS_LOST,         /**< The window has lost keyboard focus */
    SDL_WINDOWEVENT_CLOSE               /**< The window manager requests that the window be closed */
}
  TSdlWindowEventID = (sdlweNone, sdlweShown, sdlweHidden, sdlweExposed,
                        sdlweMoved, sdlweResized, sdlweMinimized, sdlweMaximized,
                        sdlweRestored, sdlweEnter, sdlweLeave, sdlweFocusGained,
                        sdlweFocusLost, sdlweClose);
  SDL_WindowEventID = TSdlWindowEventID;
  {$EXTERNALSYM SDL_WindowEventID}



{The following enums are declared in SDL_Video.h, but never actually used as
enumerated types.  They're just sets of constants that get OR'd together to make
a bitfield.  Redefining them here since Delphi has a better way of making
bitfields. Final values ensure that the set will be 32 bits in size.}

(*{
 * SDL_WindowFlags
 *
 * The flags on a window

    SDL_WINDOW_FULLSCREEN = 0x00000001,         /**< fullscreen window, implies borderless */
    SDL_WINDOW_OPENGL = 0x00000002,             /**< window usable with OpenGL context */
    SDL_WINDOW_SHOWN = 0x00000004,              /**< window is visible */
    SDL_WINDOW_BORDERLESS = 0x00000008,         /**< no window decoration */
    SDL_WINDOW_RESIZABLE = 0x00000010,          /**< window can be resized */
    SDL_WINDOW_MINIMIZED = 0x00000020,          /**< minimized */
    SDL_WINDOW_MAXIMIZED = 0x00000040,          /**< maximized */
    SDL_WINDOW_INPUT_GRABBED = 0x00000100,      /**< window has grabbed input focus */
    SDL_WINDOW_INPUT_FOCUS = 0x00000200,        /**< window has input focus */
    SDL_WINDOW_MOUSE_FOCUS = 0x00000400,        /**< window has mouse focus */
    SDL_WINDOW_FOREIGN = 0x00000800             /**< window not created by SDL */
} SDL_WindowFlags; *)
  TSdlWindowFlags = set of (sdlwFullscreen, sdlwOpenGl, sdlwShown,
                    sdlwBorderless, sdlwResizable, sdlwMinimized, sdlwMaximized,
                    sdlwInputGrabbed, dslwInputFocus, sdlwMouseFocus,
                    sdwlForeign, sdlwForce32 = 31);
  SDL_WindowFlags = TSdlWindowFlags;
  {$EXTERNALSYM SDL_WindowFlags}

(*{
 * SDL_RendererFlags
 *
 * Flags used when creating a rendering context

    SDL_RENDERER_SINGLEBUFFER = 0x00000001,     /**< Render directly to the window, if possible */
    SDL_RENDERER_PRESENTCOPY = 0x00000002,      /**< Present uses a copy from back buffer to the front buffer */
    SDL_RENDERER_PRESENTFLIP2 = 0x00000004,     /**< Present uses a flip, swapping back buffer and front buffer */
    SDL_RENDERER_PRESENTFLIP3 = 0x00000008,     /**< Present uses a flip, rotating between two back buffers and a front buffer */
    SDL_RENDERER_PRESENTDISCARD = 0x00000010,   /**< Present leaves the contents of the backbuffer undefined */
    SDL_RENDERER_PRESENTVSYNC = 0x00000020,     /**< Present is synchronized with the refresh rate */
    SDL_RENDERER_ACCELERATED = 0x00000040       /**< The renderer uses hardware acceleration */
} SDL_RendererFlags; *)
  TSdlRendererFlag = (sdlrSingleBuffer, sdlrPresentCopy, sdlrPresentFlip2,
                      sdlrPresentFlip3, sdlrPresentDiscard, sdlrPresentVsync,
                      sdlrAccelerated, sdlrForce32 = 31);
  TSdlRendererFlags = set of TSdlRendererFlag;

(*{
    SDL_TEXTUREMODULATE_NONE = 0x00000000,     /**< No modulation */
    SDL_TEXTUREMODULATE_COLOR = 0x00000001,    /**< srcC = srcC * color */
    SDL_TEXTUREMODULATE_ALPHA = 0x00000002     /**< srcA = srcA * alpha */
} SDL_TextureModulate; *)
  //"none" left out because a 0 value would break the set.
  //SDL_TEXTUREMODULATE_NONE = []
  TSdlTextureModulate = (sdltmColor, sdltmAlpha, sdltmForce32 = 31);
  TSdlTextureModulates = set of TSdlTextureModulate;

(*{
    SDL_BLENDMODE_NONE = 0x00000000,     /**< No blending */
    SDL_BLENDMODE_MASK = 0x00000001,     /**< dst = A ? src : dst (alpha is mask) */
    SDL_BLENDMODE_BLEND = 0x00000002,    /**< dst = (src * A) + (dst * (1-A)) */
    SDL_BLENDMODE_ADD = 0x00000004,      /**< dst = (src * A) + dst */
    SDL_BLENDMODE_MOD = 0x00000008       /**< dst = src * dst */
} SDL_BlendMode;*)
  //"none" left out because a 0 value would break the set.
  //SDL_BLENDMODE_NONE = []
   TSdlBlendMode = (sdlbMask, sdlbBlend, sdlbAdd, sdlbMod, sdlbForce32 = 31);
   TSdlBlendModes = set of TSdlBlendMode;

(*{
    SDL_TEXTURESCALEMODE_NONE = 0x00000000,     /**< No scaling, rectangles must match dimensions */
    SDL_TEXTURESCALEMODE_FAST = 0x00000001,     /**< Point sampling or equivalent algorithm */
    SDL_TEXTURESCALEMODE_SLOW = 0x00000002,     /**< Linear filtering or equivalent algorithm */
    SDL_TEXTURESCALEMODE_BEST = 0x00000004      /**< Bicubic filtering or equivalent algorithm */
} SDL_TextureScaleMode;*)
  //"none" left out because a 0 value would break the set.
  //SDL_TEXTURESCALEMODE_NONE = []
  TSdlTextureScaleMode = (sdltsFast, sdltsSlow, sdltsBest, sdltsForce32 = 31);
  TSdlTextureScaleModes = set of TSdlTextureScaleMode;

  PSDL_RendererInfo = ^TSDL_RendererInfo;
  TSDL_RendererInfo = record
    name: PAnsiChar;                    // The name of the renderer
    flags: TSdlRendererFlags;           // Supported SDL_RendererFlags
    mod_modes: TSdlTextureModulates;    // Supported channel modulations
    blend_modes: TSdlBlendModes;        // Supported blend modes
    scale_modes: TSdlTextureScaleModes; // Supported scale modes
    num_texture_formats: cardinal;      // The number of available texture formats
    texture_formats: array[0..19] of cardinal; // The available texture formats
    max_texture_width: integer;         // The maximimum texture width */
    max_texture_height: integer;        // The maximimum texture height */
  end;

  SDL_RendererInfo = TSDL_RendererInfo;
  {$EXTERNALSYM SDL_RendererInfo}

  PPSDL_Rect = ^PSDL_Rect;
  PSDL_Rect = ^TSDL_Rect;
  TSDL_Rect = TRect;
  SDL_Rect = TSDL_Rect;
  {$EXTERNALSYM SDL_Rect}

function SDL_CreateWindowFrom(data: HWND): TSdlWindowId; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_CreateWindowFrom}

procedure SDL_DestroyWindow(windowID: TSdlWindowID); cdecl; external SDLLibName;
{$EXTERNALSYM SDL_DestroyWindow}

function SDL_GetWindowFlags(windowID: TSdlWindowID): TSdlWindowFlags; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_GetWindowFlags}

procedure SDL_ShowWindow(windowID: TSdlWindowID); cdecl; external SDLLibName;
{$EXTERNALSYM SDL_ShowWindow}

function SDL_GetNumRenderDrivers(): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_GetNumRenderDrivers}

function SDL_GetRenderDriverInfo(index: integer; var info: TSDL_RendererInfo): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_GetRenderDriverInfo}

function SDL_CreateRenderer(windowID: TSdlWindowID; index: integer; flags: TSdlRendererFlags): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_CreateRenderer}

function SDL_SelectRenderer(windowID: TSdlWindowID): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_SelectRenderer}

function SDL_SetRenderDrawColor(r, g, b, a: byte): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_SetRenderDrawColor}

function SDL_RenderFill(const rect: PSDL_Rect): integer; cdecl; external SDLLibName;
{$EXTERNALSYM SDL_RenderFill}

implementation

end.
